# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ConnectsResult',
    'AwaitableConnectsResult',
    'connects',
    'connects_output',
]

@pulumi.output_type
class ConnectsResult:
    """
    A collection of values returned by Connects.
    """
    def __init__(__self__, id=None, occs=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if occs and not isinstance(occs, list):
            raise TypeError("Expected argument 'occs' to be a list")
        pulumi.set(__self__, "occs", occs)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def occs(self) -> Sequence['outputs.ConnectsOccResult']:
        return pulumi.get(self, "occs")


class AwaitableConnectsResult(ConnectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return ConnectsResult(
            id=self.id,
            occs=self.occs)


def connects(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableConnectsResult:
    """
    Get the details of your Ovhcloud Connect products.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    occs = ovh.OVHcloud.connect()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:OVHcloud/connects:Connects', __args__, opts=opts, typ=ConnectsResult).value

    return AwaitableConnectsResult(
        id=pulumi.get(__ret__, 'id'),
        occs=pulumi.get(__ret__, 'occs'))
def connects_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[ConnectsResult]:
    """
    Get the details of your Ovhcloud Connect products.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    occs = ovh.OVHcloud.connect()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:OVHcloud/connects:Connects', __args__, opts=opts, typ=ConnectsResult)
    return __ret__.apply(lambda __response__: ConnectsResult(
        id=pulumi.get(__response__, 'id'),
        occs=pulumi.get(__response__, 'occs')))
